/*-
 * ~~~~~~licensing~~~~~~
 * bundle-manager
 * ==========
 * Copyright (C) 2020 - 2021 EmDev LLC
 * ==========
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ~~~~~~/licensing~~~~~~
 */
package ru.entaxy.esb.system.management.bundle.manager;

import ru.entaxy.esb.system.management.blueprint.generator.Blueprint;
import ru.entaxy.esb.system.management.bundle.jpa.dto.BundleDto;

import java.net.URL;
import java.util.Map;

public interface BundleManager {

    BundleDto installAndStartBundle(String bundleName, String bundleType, String bundleVersion,
                                    Map<String, String> param) throws Exception;
    
    BundleDto installBundle(String bundleName, String templateName, String templateFileName, String bundleType, String bundleVersion,
			URL templateUrl, Map<String, String> param) throws Exception;
    
    BundleDto installAndStartBundle(String bundleName, String bundleType, String bundleVersion, Blueprint blueprint) throws Exception;
    
    BundleDto installBundle(String bundleName, String bundleType, String bundleVersion, Blueprint blueprint) throws Exception;

    BundleDto installAndStartBundle(String bundleName, String bundleType, String bundleVersion) throws Exception;

    BundleDto installBundle(String bundleName, String bundleType, String bundleVersion) throws Exception;

    BundleDto startBundle(BundleDto bundle) throws Exception;

    BundleDto stopBundle(BundleDto bundle) throws Exception;

    void uninstallBundle(String bundleName, String type, String bundleVersion) throws Exception;

    BundleDto installAndStartBundle(String bundleName, String templateName, String templateFileName, String bundleType, String bundleVersion,
                                    URL url, Map<String, String> param) throws Exception;
    
    BundleDto installBundle(String bundleName, String bundleType, String bundleVersion, Map<String, String> param)
			throws Exception;

    void uninstallBundleByName(String bundleName, String type, String bundleVersion) throws Exception;

	void restore(BundleDto bundle) throws Exception;

	void checkCurrentBundleStatus(BundleDto bundle) throws Exception;

	

	

}
